@@ -154,15 +154,9 @@ void qpwgraph_canvas::setPatchbayEdit ( bool on )
 		( on &&  m_patchbay_edit))
 		return;
 
-	foreach (QGraphicsItem *item, m_scene->items()) {
-		if (item->type() == qpwgraph_connect::Type) {
-			qpwgraph_connect *connect = static_cast<qpwgraph_connect *> (item);
-			if (connect)
-				connect->setDimmed(on && !m_patchbay->findConnect(connect));
-		}
-	}
-
 	m_patchbay_edit = on;
+
+	patchbayEdit();
 }
 
 
@@ -172,6 +166,20 @@ bool qpwgraph_canvas::isPatchbayEdit (void) const
 }
 
 
+void qpwgraph_canvas::patchbayEdit (void)
+{
+	foreach (QGraphicsItem *item, m_scene->items()) {
+		if (item->type() == qpwgraph_connect::Type) {
+			qpwgraph_connect *connect = static_cast<qpwgraph_connect *> (item);
+			if (connect) {
+				connect->setDimmed(
+					m_patchbay_edit && !m_patchbay->findConnect(connect));
+			}
+		}
+	}
+}
+
+
 bool qpwgraph_canvas::canPatchbayPin (void) const
 {
 	if (m_patchbay == nullptr || !m_patchbay_edit)
